==> gridx-1.3-javadoc.jar: nls/ca/gridx.js <==
define({     
//Body
	loadingInfo: "Carregant...",
	emptyInfo: "No hi ha elements per visualitzar",
	loadFailInfo: "No s'han pogut carregar les dades.",
	loadMore: "Carrega'n més",
	loadMoreLoading: "Carregant...",
	loadPrevious: "Carrega l'anterior",
	loadPreviousLoading: "Carregant...",

//FilterBar
	"clearFilterDialogTitle": "Esborra filtre",
	"filterDefDialogTitle": "Filtra",
	"defaultRuleTitle": "Regla",
	"ruleTitleTemplate": "Regla ${ruleNumber}",
	"noFilterApplied": "No s'ha aplicat cap filtre.",
	"defineFilter": "Defineix filtre",
	"conditionEqual": "és igual a",
	"conditionNotEqual": "no és igual a",
	"conditionLess": "és menor que",
	"conditionLessEqual": "és menor o igual que",
	"conditionGreater": "és major que",
	"conditionGreaterEqual": "és major o igual que",
	"conditionContain": "conté",
	"conditionIs": "és",
	"conditionStartWith": "comença per",
	"conditionEndWith": "acaba en",
	"conditionNotContain": "no conté",
	"conditionIsNot": "no és",
	"conditionNotStartWith": "no comença per",
	"conditionNotEndWith": "no acaba en",
	"conditionBefore": "abans",
	"conditionAfter": "després",
	"conditionRange": "interval",
	"conditionIsEmpty": "és buit",
	"all": "tot",
	"any": "qualsevol",
	"relationAll": "totes les regles",
	"waiRelAll": "Coincideix amb totes les regles següents:",
	"relationAny": "qualsevol regla",
	"waiRelAny": "Coincideix amb alguna de les regles següents:",
	"relationMsgFront": "Coincidència",
	"relationMsgTail": "",
	"and": "i",
	"or": "o",
	"addRuleButton": "Afegeix regla",
	"waiAddRuleButton": "Afegeix una nova regla",
	"removeRuleButton": "Elimina la regla",
	"waiRemoveRuleButtonTemplate": "Elimina la regla ${0}",
	"addRuleButton": "Afegeix regla de filtre",
	"cancelButton": "Cancel·la",
	"waiCancelButton": "Cancel·la aquest diàleg",
	"clearButton": "Esborra",
	"waiClearButton": "Esborra el filtre",
	"filterButton": "Filtra",
	"waiFilterButton": "Envia el filtre",
	"columnSelectLabel": "Columna:",
	"waiColumnSelectTemplate": "Columna per a la regla ${0}",
	"conditionSelectLabel": "Condició:",
	"waiConditionSelectTemplate": "Condició per a la regla ${0}",
	"valueBoxLabel": "Valor:",
	"waiValueBoxTemplate": "Escriviu el valor de filtre per a la regla ${0}",
	"rangeTo": "a",
	"rangeTemplate": "de ${0} a ${1}",
	"statusTipHeaderColumn": "Columna",
	"statusTipHeaderCondition": "Regles",
	"statusTipTitle": "Barra de filtre",
	"statusTipMsg": "Feu clic a la barra de filtre per filtrar valors a ${0}.",
	"anycolumn": "qualsevol columna",
	"statusTipTitleNoFilter": "Barra de filtre",
	"statusTipTitleHasFilter": "Filtra",
	"statusTipRelPre": "Coincidència",
	"statusTipRelPost": "regles.",
	"statusTipHeaderAll": "Coincideix amb totes les regles.",
	"statusTipHeaderAny": "Coincideix amb qualsevol regla.",
	"defaultItemsName": "elements",
	"filterBarMsgHasFilterTemplate": "Es visualitzen ${0} de ${1} ${2}.",
	"filterBarMsgNoFilterTemplate": "No s'ha aplicat cap filtre",
	"filterBarDefButton": "Defineix filtre",
	"waiFilterBarDefButton": "Filtra la taula",
	"a11yFilterBarDefButton": "Filtra...",
	"filterBarClearButton": "Esborra el filtre",
	"waiFilterBarClearButton": "Esborra el filtre",
	"closeFilterBarBtn": "Tanca la barra de filtre",
	"clearFilterMsg": "S'eliminarà el filtre i es mostraran tots els registre disponibles.",
	"anyColumnOption": "Qualsevol columna",
	"trueLabel": "Veritable",
	"falseLabel": "Fals",
	"radioTrueLabel": "Valor veritable",
	"radioFalseLabel": "Valor fals",
	"beginTimeRangeLabel": "Valor d'inici de l'interval d'hora",
	"endTimeRangeLabel": "Valor final de l'interval d'hora",
	"beginDateRangeLabel": "Inici del valor d'interval de data",
	"endDateRangeLabel": "Final del valor d'interval de data",
	"startsWithExpr": "${0}*",

//NestedSort
	singleSort: "Ordenació única",
	nestedSort: "Ordenació imbricada",
	ascending: "Feu-hi clic que ordenar de forma ascendent",
	descending: "Feu-hi clic que ordenar de forma descendent",
	sortingState: "${0} - ${1}",
	unsorted: "No ordenis aquesta columna",
	waiSingleSortLabel: "${0} - s'ordena per ${1}. Trieu ordenar per ${2}",
	waiNestedSortLabel:"${0} - s'ordena de forma imbricada per ${1}. Trieu d'ordenar de forma imbricada per ${2}",

//PaginationBar
	pagerWai: 'Paginador',

	pageIndex: '${0}',
	pageIndexTitle: 'Pàgina ${0}',

	firstPageTitle: 'Primera pàgina',
	prevPageTitle: 'Pàgina anterior',
	nextPageTitle: 'Pàgina següent',
	lastPageTitle: 'Última pàgina',

	pageSize: '${0}',
	pageSizeTitle: '${0} elements per pàgina',
	pageSizeAll: 'Tot',
	pageSizeAllTitle: 'Tots els elements',

	description: '${0} - ${1} de ${2} elements.',
	descriptionEmpty: 'La graella és buida.',

	summary: 'Total: ${0}',
	summaryWithSelection: 'Total: ${0} Seleccionats: ${1}',

	gotoBtnTitle: 'Vés a una pàgina específica',

	gotoDialogTitle: 'Vés a la pàgina',
	gotoDialogMainMsg: 'Especifica el número de pàgina:',
	gotoDialogPageCount: '(${0} pàgines)',
	gotoDialogOKBtn: 'Vés-hi',
	gotoDialogCancelBtn: 'Cancel·la',
	// for drop down pagination bar
	pageLabel: 'Pàgina',
	pageSizeLabel: 'Files',

//QuickFilter
	filterLabel: 'Filtra',
	clearButtonTitle: 'Esborra filtre',
	buildFilterMenuLabel: 'Crea filtre&hellip;',
	apply: 'Aplica filtre',

//Sort
	helpMsg: '${0} - Fes clic per ordenar o control-clic per afegir a l\'ordenació',
	singleHelpMsg: '${0} - Fes clic per ordenar',
	priorityOrder: 'prioritat d\'ordenació ${0}',

//SummaryBar
	summaryTotal: 'Total: ${0}',
	summarySelected: 'Seleccionats: ${0}',
	summaryRange: 'Interval: ${0}-${1}',	//need translation

//Other
	indirectSelectAll: "Premeu ESPAI per seleccionar-ho tot.",	//need translation
	indirectDeselectAll: "Premeu ESPAI per deseleccionar-ho tot.",	//need translation
	treeExpanded: "Control + tecla de fletxa esquerra per contraure aquesta fila. ",	//need translation
	treeCollapsed: "Control + tecla de fletxa dreta per expandir aquesta fila. "	//need translation
});

==> gridx-1.3.9-javadoc.jar: nls/ca/gridx.js <==
define({     
//Body
	loadingInfo: "Carregant...",
	emptyInfo: "No hi ha elements per visualitzar",
	loadFailInfo: "No s'han pogut carregar les dades.",
	loadMore: "Carrega'n més",
	loadMoreLoading: "Carregant...",
	loadPrevious: "Carrega l'anterior",
	loadPreviousLoading: "Carregant...",

//FilterBar
	"clearFilterDialogTitle": "Esborra filtre",
	"filterDefDialogTitle": "Filtra",
	"defaultRuleTitle": "Regla",
	"ruleTitleTemplate": "Regla ${ruleNumber}",
	"noFilterApplied": "No s'ha aplicat cap filtre.",
	"defineFilter": "Defineix filtre",
	"defineFilterAriaLabel": "Defineix filtre: S'obre un diàleg de filtre per configurar regles de filtre complexes. Cada regla de filtre està formada per una combinació d'una columna, una condició i un valor. Quan s'obre el diàleg, el camp del valor està activat. ",
	"conditionEqual": "és igual a",
	"conditionNotEqual": "no és igual a",
	"conditionLess": "és menor que",
	"conditionLessEqual": "és menor o igual que",
	"conditionGreater": "és major que",
	"conditionGreaterEqual": "és major o igual que",
	"conditionContain": "conté",
	"conditionIs": "és",
	"conditionStartWith": "comença per",
	"conditionEndWith": "acaba en",
	"conditionNotContain": "no conté",
	"conditionIsNot": "no és",
	"conditionNotStartWith": "no comença per",
	"conditionNotEndWith": "no acaba en",
	"conditionBefore": "abans",
	"conditionAfter": "després",
	"conditionRange": "interval",
	"conditionIsEmpty": "és buit",
	"conditionIsNotEmpty": "no està buit",
	"all": "tot",
	"any": "qualsevol",
	"relationAll": "totes les regles",
	"waiRelAll": "Coincideix amb totes les regles següents:",
	"relationAny": "qualsevol regla",
	"waiRelAny": "Coincideix amb alguna de les regles següents:",
	"relationMsgFront": "Coincidència",
	"relationMsgTail": "",
	"and": "i",
	"or": "o",
	"addRuleButton": "Afegeix regla",
	"waiAddRuleButton": "Afegeix una nova regla",
	"removeRuleButton": "Elimina la regla",
	"waiRemoveRuleButtonTemplate": "Elimina la regla ${0}",
	"addRuleButton": "Afegeix regla de filtre",
	"cancelButton": "Cancel·la",
	"waiCancelButton": "Cancel·la aquest diàleg",
	"clearButton": "Esborra",
	"waiClearButton": "Esborra el filtre",
	"filterButton": "Filtra",
	"waiFilterButton": "Envia el filtre",
	"columnSelectLabel": "Columna:",
	"columnSelectAriaLabel": "Columna: part de la condició ${0} de ${1}",
	"waiColumnSelectTemplate": "Columna per a la regla ${0}",

	"conditionSelectLabel": "Condició:",
	"conditionSelectAriaLabel": "Operador: part de la condició ${0} de ${1}",
	"waiConditionSelectTemplate": "Condició per a la regla ${0}",

	"valueBoxLabel": "Valor:",
	"valueBoxAriaLabel": "Valor: part de la condició ${0} de ${1}",
	"waiValueBoxTemplate": "Escriviu el valor de filtre per a la regla ${0}",
	"rangeTo": "a",
	"rangeTemplate": "de ${0} a ${1}",
	"statusTipHeaderColumn": "Columna",
	"statusTipHeaderCondition": "Regles",
	"statusTipTitle": "Barra de filtre",
	"statusTipMsg": "Feu clic a la barra de filtre per filtrar valors a ${0}.",
	"anycolumn": "qualsevol columna",
	"statusTipTitleNoFilter": "Barra de filtre",
	"statusTipTitleHasFilter": "Filtra",
	"statusTipRelPre": "Coincidència",
	"statusTipRelPost": "regles.",
	"statusTipHeaderAll": "Coincideix amb totes les regles.",
	"statusTipHeaderAny": "Coincideix amb qualsevol regla.",
	"defaultItemsName": "elements",
	"filterBarMsgHasFilterTemplate": "Es visualitzen ${0} de ${1} ${2}.",
	"filterBarMsgNoFilterTemplate": "No s'ha aplicat cap filtre",
	"filterBarDefButton": "Defineix filtre",
	"waiFilterBarDefButton": "Filtra la taula",
	"a11yFilterBarDefButton": "Filtra...",
	"filterBarClearButton": "Esborra el filtre",
	"waiFilterBarClearButton": "Esborra el filtre",
	"closeFilterBarBtn": "Tanca la barra de filtre",
	"clearFilterMsg": "S'eliminarà el filtre i es mostraran tots els registre disponibles.",
	"anyColumnOption": "Qualsevol columna",
	"trueLabel": "Veritable",
	"falseLabel": "Fals",
	"radioTrueLabel": "Valor veritable",
	"radioFalseLabel": "Valor fals",
	"beginTimeRangeLabel": "Valor d'inici de l'interval d'hora",
	"endTimeRangeLabel": "Valor final de l'interval d'hora",
	"beginDateRangeLabel": "Inici del valor d'interval de data",
	"endDateRangeLabel": "Final del valor d'interval de data",
	"startsWithExpr": "${0}*",

//NestedSort
	singleSort: "Ordenació única",
	nestedSort: "Ordenació imbricada",
	ascending: "Feu-hi clic que ordenar de forma ascendent",
	descending: "Feu-hi clic que ordenar de forma descendent",
	sortingState: "${0} - ${1}",
	unsorted: "No ordenis aquesta columna",
	waiSingleSortLabel: "${0} - s'ordena per ${1}. Trieu ordenar per ${2}",
	waiNestedSortLabel:"${0} - s'ordena de forma imbricada per ${1}. Trieu d'ordenar de forma imbricada per ${2}",

//PaginationBar
	pagerWai: 'Paginador',

	pageIndex: '${0}',
	pageIndexTitle: 'Pàgina ${0}',

	firstPageTitle: 'Primera pàgina',
	prevPageTitle: 'Pàgina anterior',
	nextPageTitle: 'Pàgina següent',
	lastPageTitle: 'Última pàgina',

	pageSize: '${0}',
	pageSizeTitle: '${0} elements per pàgina',
	pageSizeAll: 'Tot',
	pageSizeAllTitle: 'Tots els elements',

	description: '${0} - ${1} de ${2} elements.',
	descriptionEmpty: 'La graella és buida.',

	summary: 'Total: ${0}',
	summaryWithSelection: 'Total: ${0} Seleccionats: ${1}',

	gotoBtnTitle: 'Vés a una pàgina específica',

	gotoDialogTitle: 'Vés a la pàgina',
	gotoDialogMainMsg: 'Especifica el número de pàgina:',
	gotoDialogPageCount: '(${0} pàgines)',
	gotoDialogOKBtn: 'Vés-hi',
	gotoDialogCancelBtn: 'Cancel·la',
	// for drop down pagination bar
	pageLabel: 'Pàgina',
	pageSizeLabel: 'Files',

//QuickFilter
	filterLabel: 'Filtra',
	clearButtonTitle: 'Esborra filtre',
	buildFilterMenuLabel: 'Crea filtre…',
	apply: 'Aplica filtre',

//Sort
	helpMsg: '${0} - Fes clic per ordenar o control-clic per afegir a l\'ordenació',
	singleHelpMsg: '${0} - Fes clic per ordenar',
	priorityOrder: 'prioritat d\'ordenació ${0}',

//SummaryBar
	summaryTotal: 'Total: ${0}',
	summarySelected: 'Seleccionats: ${0}',
	summaryRange: 'Interval: ${0}-${1}',	//need translation

//Other
	indirectSelectAll: "Premeu ESPAI per seleccionar-ho tot.",	//need translation
	indirectDeselectAll: "Premeu ESPAI per deseleccionar-ho tot.",	//need translation
	treeExpanded: "Control + tecla de fletxa esquerra per contraure aquesta fila. ",	//need translation
	treeCollapsed: "Control + tecla de fletxa dreta per expandir aquesta fila. "	//need translation
});
